==> mkvtoolnix-0.8.9.tar.bz2: mkvtoolnix-0.8.9/src/output/p_vorbis.h <==
/*
  mkvmerge -- utility for splicing together matroska files
      from component media subtypes

  p_vorbis.h

  Written by Moritz Bunkus <moritz@bunkus.org>

  Distributed under the GPL
  see the file COPYING for details
  or visit http://www.gnu.org/copyleft/gpl.html
*/

/*!
    \file
    \version $Id: p_vorbis.h 1657 2004-04-09 17:37:25Z mosu $
    \brief class definition for the Vorbis packetizer
    \author Moritz Bunkus <moritz@bunkus.org>
*/

#include "config.h"

#ifndef __P_VORBIS_H
#define __P_VORBIS_H

#include "os.h"

#include <ogg/ogg.h>
#include <vorbis/codec.h>

#include "common.h"
#include "pr_generic.h"
#include "pr_generic.h"

class vorbis_packetizer_c: public generic_packetizer_c {
private:
  int64_t last_bs, samples;
  int packetno;
  vorbis_info vi;
  vorbis_comment vc;
  ogg_packet headers[3];
public:
  vorbis_packetizer_c(generic_reader_c *nreader,
                      unsigned char *d_header, int l_header,
                      unsigned char *d_comments, int l_comments,
                      unsigned char *d_codecsetup, int l_codecsetup,
                      track_info_c *nti) throw (error_c);
  virtual ~vorbis_packetizer_c();

  virtual int process(memory_c &mem, int64_t timecode = -1,
                      int64_t length = -1, int64_t bref = -1,
                      int64_t fref = -1);
  virtual void set_headers();

  virtual void dump_debug_info();

  virtual const char *get_format_name() {
    return "Vorbis";
  }
  virtual int can_connect_to(generic_packetizer_c *src);
};

#endif  // __P_VORBIS_H

==> mkvtoolnix-1.0.1.tar.bz2: mkvtoolnix-1.0.1/src/output/p_vorbis.h <==
/*
 * mkvmerge -- utility for splicing together matroska files
 * from component media subtypes
 *
 * Distributed under the GPL
 * see the file COPYING for details
 * or visit http://www.gnu.org/copyleft/gpl.html
 *
 * $Id: p_vorbis.h 2359 2004-10-16 13:46:49Z mosu $
 *
 * class definition for the Vorbis packetizer
 *
 * Written by Moritz Bunkus <moritz@bunkus.org>.
 */

#include "config.h"

#ifndef __P_VORBIS_H
#define __P_VORBIS_H

#include "os.h"

#include <ogg/ogg.h>
#include <vorbis/codec.h>

#include "common.h"
#include "pr_generic.h"
#include "pr_generic.h"

class vorbis_packetizer_c: public generic_packetizer_c {
private:
  int64_t last_bs, samples, last_samples_sum, last_timecode, timecode_offset;
  vorbis_info vi;
  vorbis_comment vc;
  ogg_packet headers[3];
public:
  vorbis_packetizer_c(generic_reader_c *nreader,
                      unsigned char *d_header, int l_header,
                      unsigned char *d_comments, int l_comments,
                      unsigned char *d_codecsetup, int l_codecsetup,
                      track_info_c *nti) throw (error_c);
  virtual ~vorbis_packetizer_c();

  virtual int process(memory_c &mem, int64_t timecode = -1,
                      int64_t length = -1, int64_t bref = -1,
                      int64_t fref = -1);
  virtual void set_headers();

  virtual void dump_debug_info();

  virtual const char *get_format_name() {
    return "Vorbis";
  }
  virtual int can_connect_to(generic_packetizer_c *src);
};

#endif  // __P_VORBIS_H
